![NuGet logo](https://raw.githubusercontent.com/NuGet/Home/dev/meta/resources/nuget.png)

-----

# NuGet Client Tools

This repo contains the following clients:

- [NuGet CLI](https://docs.microsoft.com/nuget/tools/nuget-exe-cli-reference)
- [NuGet Package Manager for Visual Studio](https://docs.microsoft.com/nuget/tools/package-manager-ui)
- [PowerShell CmdLets](https://docs.microsoft.com/nuget/tools/powershell-reference)
- [NuGet functionality for dotnet.exe](https://docs.microsoft.com/en-us/dotnet/core/tools/dotnet)

## Open Source Code of Conduct

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/). For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or contact [opencode@microsoft.com](mailto:opencode@microsoft.com) with any additional questions or comments.

## Getting Started guide

For how to contribute to this repo follow the [Contributing doc](CONTRIBUTING.md).

## NuGet/Home repo

The [NuGet/Home](https://github.com/nuget/Home) repo is the starting point for all things NuGet. It has the [issue tracker](https://github.com/nuget/home/issues) and [basic information](https://github.com/nuget/home) about all things NuGet. Make sure to consult it before beginning your journey through NuGet code.

## Feedback

File NuGet.Client bugs in the [NuGet/Home](https://github.com/nuget/home/issues).

## License

Unless explicitly stated otherwise all files in this repository are licensed under the License in the root repository
